/**
 * 
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 * 
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 * 
 * Copyright (C) 2003-2010 Open-Xchange, Inc.
 * Mail: info@open-xchange.com 
 * 
 * @author Jan Finsel <jan.finsel@open-xchange.com>
 * 
 */

register("Loaded",function(){
});

/**
 * Object ID of the currently displayed folder, or <code>null</code> if no
 * specific folder is displayed.
 */
var activefolder = null;
/**
 * -1 if Configuration Folder Edit
 * [parentfolder] if Configuration Folder New
 *
 */
var configparentfolder=-1;
var superzaehler=1;
/*ID des Reiters im Modul */
// Remove this
var menuarrows=new Object();


register("OX_Direct_Linking",
	function(modulename,object)
	{
		menufollowLink(modulename,object);
	}	
);
var blockremoveerrors=false;
register("OX_GLOBAL_CLICK",
	function ()
	{
		if(!blockremoveerrors) {
			menuremoveErrors(4);
		}
		blockremoveerrors=false;
	});


register("OX_Show_Help_Panel",showPanelHelp);
register("OX_menu_Change_Height",menuHeightChange);
register("OX_menu_Change_Height",menuHeightChangePicture);
resizeEvents.register("Resized", reloadDynamicContent);
register("OX_menu_After_Change_Height",reloadDynamicContent);
register("OX_menu_RESIZE",resizeMenuSplit);
var errorlist=new MRUList(15);

function showErrorinPopup() {
	var d=$("error_popup_messages");
	removeChildNodes(d);
	var hasErrors=false;
	for(var i in corewindow.errorlist.cache) {
		hasErrors=true;
		var element=corewindow.errorlist.get(i);
		var newnode=$("error_messages_template").cloneNode(true);
		newnode.id="";
		newnode.getElementsByTagName("td")[0].firstChild.data=formatDate(element.time,"datetime")+"-->"+formatError(element);
		d.appendChild(newnode);
		newnode.style.display="";
	}
	if(hasErrors) {
		
	} else {
		var newnode=$("error_messages_template").cloneNode(true);
		newnode.id="";
		newnode.getElementsByTagName("td")[0].firstChild.data=_("No error occured");
		d.appendChild(newnode);
		newnode.style.display="";
	}
	ErrorPopup.openWindow();
}
function newServerError(args,level) {
	if(!level) { level=4; }
	if(args.error) {
		var sizes = {
			"MSG-0028": [0, 2], "MSG-0029": [0], "NON-0005": [0, 1],
			"AJP-0006": [0], "FLS-0003": [0, 1, 2], "CON-0101": [1, 2],
			"AJP-0020": [0, 1]
		}[args.code];
		if (sizes) {
			for (var i = 0; i < sizes.length; i++)
				args.error_params[sizes[i]] = bytesToString(args.error_params[sizes[i]]);
		}
		corewindow.storeError(clone(args),level);
		triggerEvent("OX_New_Error",level,formatError(args));		
	}
}
function storeError(args1,level) {
	var myel=clone(args1);
	args1.time=new Date();
	myel.time=new Date(Date.UTC(args1.time.getFullYear(),args1.time.getMonth(),args1.time.getDate(),args1.time.getHours(),args1.time.getMinutes(),0,0));
	errorlist.set(myel.error_id,myel);
}
register("OX_New_Error",
	function (errorprio,errormessage)
	{
		addErrorMessage(errorprio,errormessage);
	});
register("OX_New_Info",
	function (errorprio,errormessage)
	{
		addInfoMessage(errorprio,errormessage);
	});
register("Loaded",loadmenu);    
/** Globale Variablen
 *
 * 0 - 6 Layouts
 */

menuconfig=new Object();
var itemsselected=0;
oxlayout=0;

/**
 * 0 day
 * 1 workweek
 * 2 month
 * 3 week
 */


var taskview=0;
	
var lang="DE";			/*Sprache die Aktiviert ist*/
var helpmessage;		/*Derzeitige Helpmessage*/
// I18N
var errormessages=new Array();
var infomessages=new Array();


/* Beschreibung Trigger */
/* OX_Email_Change_Structure		Struktur Ansicht einer EMail hat sich ge?ndert
 * 
 */
/*menunvariablen */
var debugit=false;
var dynamicdatacontent      	= new Array(); /* Alle dynamischen Contents */
var menu_complete				= 0;  /*Komplette Gr????e menu*/
var menu_dynamic_scroller		= 0;  /*Gr????e dynamischer Scroller*/

var menu_dynamic_rightscroll	= 0;  /*dynamisch Rechts Gr??e*/
var menu_dynamic				= 0;  /*menu Dynamisch Gr??e mit Links und Rechts*/
var menu_dynamic_content		= 0;  /*menu Dynamisch Content Gr????e*/
var status_content				= 0;  /*derzeitiger Status*/


var dynamiccontents=new Object();			 /* Alle dynamischen Contents */
var corecontents=new Array();
var allcontentspicturepopup=new Array();     /* Alle Contents der Picture Popups */

var menu_modules=new Array();

var menuminiteration = 2;
var menuiterationheight=1.6;
var menupadding=0.4;
var menumaxiteration=6;		
var menuiteration=4;

var menupictureiterationmin=3;
var menupictureiterationheight=menupictureiterationmin-1;

var headerheight=1.5;		 /* min. height of each panel row */
var arrowheight=0.7;
var erroriteration=2;
var menuerrorheight=1.6;
var menuhelpheight=3.6;
var menunhelphoehemin=1;

var newmodule=-1;

var errorid=0;
var popshow=false;
var clickedinpopup=false;
var showhelp=false;

/********************************** New Registrations ************************************************************/
var menulastviews = new Object();
register("OX_Configuration_Set_Empty",loadDefaultModules);
function loadDefaultModules() {
	for (var i in modules) {
		if(configContainsKey("gui."+modules[i].name+".view")) 
		{
			if(modules[i].name == "calendar" && !configGetKey("modules.calendar.calendar_teamview") &&(configGetKey("gui."+modules[i].name+".view").indexOf("calendar/team") == 0 )) {
				configSetKey("gui."+modules[i].name+".view","calendar/calendar/day");
			}
			menulastviews[modules[i].name] = configGetKey("gui."+modules[i].name+".view");
			
		} else {
			if(modules[i].name== "configuration") {
				menulastviews[modules[i].name] = "configuration/settings";
			}
			else {
				menulastviews[modules[i].name] = modules[i].name;
			}
		}
	}
}

register("OX_Switch_Module",switchtoModule);
function switchtoModule(newmodule,param,folder) {
	menuremoveErrors(2);
	if (newmodule == "mail" && folder == configGetKey("mail.folder.spam")) {
		changeView(configGetKey("gui.mail.view_spam") || "mail/list/unthreaded", param);
	} else if (menulastviews[newmodule]) {
		changeView(menulastviews[newmodule],param);
	} else {
		alert("Unknown Module view "+newmodule);
	}
	status_content=0;  // Neues Modul -- Dynamischer Content auf Start
	reloadDynamicContent();
	triggerEvent("OX_Switched");
}

register("OX_Switch_View",switchtoView);
function switchtoView(newview,param) {
	var newmodule=newview.split("/")[0];
	(newmodule!=activemodule) ? menuremoveErrors(2) : menuremoveErrors(3);
	if(isDefaultableView(newview)) {
		menulastviews[newmodule]=newview;
	}
	changeView(newview,param);
	reloadDynamicContent();
	triggerEvent("OX_Switched");
}

function initDisplay(view,elementid,setwidth) {

	var views=view.split("/");
	var tmp=new Object();
	if(!setwidth) {
		tmp.content=$(elementid);
		tmp.content.style.display="";
		tmp.width=tmp.content.offsetWidth;
		tmp.content.style.display="none";
	} else {
		tmp.width=setwidth;
	}
	
	tmp.id=tmp.content.id;
	tmp.view=view;
	// LOAD FROM CONFIG (TODO)
	tmp["display"]="block";
	if(!dynamiccontents[views[0]]) {
		dynamiccontents[views[0]]= new Array();
	}
	dynamiccontents[views[0]].push(tmp);
}

/**
 * Shows or hides a menu element in the specified view.
 * @param {String} name The name of the view as used for registerView.
 * @param {String} id The ID of the DOM node which will be shown in the view.
 * @param {Boolean} hide If true, a previously shown element will be hidden.
 */
function changeDisplay(name, id, hide) {
    var key = name + "\x00" + id;
    if (hide) {
        var change = changeDisplay.changes[key];
        if (change) {
            change.view.show[change.index] = undefined;
            change.view.hide[change.index] = undefined;
        } else {
            console.error("Invalid changeDisplay", name, id);
        }
    } else {
        var v = registerView(name, function() { showNode(id); },
            null,null, function() { hideNode(id); });
        changeDisplay.changes[key] = { view: v, index: v.show.length - 1 };
    }
}
changeDisplay.changes = {};

/*** Global ***/
changeDisplay("portal","menu_picture");
changeDisplay("portal","menu_portal_quick_settings");

changeDisplay("mail","menu_picture");
changeDisplay("mail","menu_mail");
changeDisplay("mail","menu_mail2");
changeDisplay("mail","menu_mail_view");
changeDisplay("mail","menu_global_tags");

changeDisplay("mail/list","menu_global_attachments");
changeDisplay("mail/hsplit","menu_global_attachments");
changeDisplay("mail/vsplit","menu_global_attachments");

function menuswitchMailView(param) {
	
	var newpath=currentpath2.slice(0);
	newpath[1]=param;
	switch (param)	{
		case "list":
		case "vsplit":
		case "hsplit":
			if(newpath[2]) {
				if(newpath[2]!="unthreaded" && newpath[2]!="threaded") {
					newpath.length=3;
					newpath[2]="unthreaded";
					break;
				}
			} else {
				newpath[2]="unthreaded";
			}
			break;
	}
	switchtoView(newpath.join("/"));
}
function menuswitchStructureView(param) {
	var newpath=currentpath2.slice(0);
	newpath[2]=param;
	newpath.length=3;
	switchtoView(newpath.join("/"));
}
changeDisplay("mail_new","menu_save_mail");
changeDisplay("mail_new","menu_new_mail");
changeDisplay("mail_new","menu_new_mail_view");
changeDisplay("mail_new","menu_dyn_window");

changeDisplay("mail_detail","menu_picture");
changeDisplay("mail_detail","menu_mail");
changeDisplay("mail_detail","menu_mail2");
changeDisplay("mail_detail","menu_global_tags");
changeDisplay("mail_detail","menu_global_attachments");
changeDisplay("mail_detail","menu_dyn_window");

changeDisplay("calendar","menu_picture");
changeDisplay("calendar","menu_calendar");
changeDisplay("calendar","menu_calendar_views");
changeDisplay("calendar","menu_global_tags");

changeDisplay("calendar/calendar","menu_calendar_timerange");
changeDisplay("calendar/team","menu_calendar_timerange");
changeDisplay("calendar/team","menu_calendar_teammember");
changeDisplay("calendar/list","menu_calendar_timerange");
changeDisplay("calendar/detail/attachment","menu_global_attachments");
changeDisplay("calendar/detail","menu_global_confirmation");

function menuswitchCalendarView(param) {
	var newpath=currentpath2.slice(0);
	newpath[1]=param;
	if(!newpath[2]) {
	}
	switch (param)	{
		case "list":
			if(newpath[2]) {
				if(newpath[2]!="day" && newpath[2]!="workweek" && newpath[2]!="month" && newpath[2]!="week") {
					newpath.length=3;
					var oldview=menulastviews["calendar"].split("/");
					if(!oldview[2]) {
						newpath[2]="day";
					}
					else if(oldview[2]!="day" && oldview[2]!="workweek" && oldview[2]!="month" && oldview[2]!="week") {
						newpath[2]="day";
					}
					else {
						newpath[2]=oldview[2];
					}
					break;
				}
			} else {
				newpath[2]="day";
			}
			break;
		case "calendar":
			if(newpath[2]) {
				if(newpath[2]!="day" && newpath[2]!="workweek" && newpath[2]!="month" && newpath[2]!="week" && newpath[2]!="custom") {
					newpath.length=3;
					var oldview=menulastviews["calendar"].split("/");
					if(!oldview[2]) {
						newpath[2]="day";
					}
					else if(oldview[2]!="day" && oldview[2]!="workweek" && oldview[2]!="month" && oldview[2]!="week" && oldview[2]!="custom") {
						newpath[2]="day";
					}
					else {
						newpath[2]=oldview[2];
					}
					break;
				}
			} else {
				newpath[2]="day";
			}
			break;		
		case "team":
			if(newpath[2]) {
				if(newpath[2]!="day" && newpath[2]!="workweek") {
					newpath.length=3;
					var oldview=menulastviews["calendar"].split("/");
					if(!oldview[2]) {
						newpath[2]="day";
					}
					else if(oldview[2]!="day" && oldview[2]!="workweek") {
						newpath[2]="day";
					}
					else {
						newpath[2]=oldview[2];
					}
					break;
				}
			} else {
				newpath[2] = "day";
			}
			break;
		case "detail":
			newpath[2]="overview";
			newpath.length=3;
			break;
	}
	switchtoView(newpath.join("/"));
}
function menuswitchCalendarTimerange(param) {
	var newpath=currentpath2.slice(0);
	newpath[2]=param;
	newpath.length=3;
	switchtoView(newpath.join("/"));
	
}
function menuswitchCalendarDetail(param) {
	var newpath=currentpath2.slice(0);
	newpath[2]=param;
	newpath.length=3;
	switchtoView(newpath.join("/"));
}

changeDisplay("calendar_new","menu_save");
changeDisplay("calendar_new/participant","menu_calendar_new_participant");
changeDisplay("calendar_new/attachment","menu_calendar_new_attachment");
changeDisplay("calendar_new","menu_dyn_window");

function menuswitchCalendarNew(param) {
	var newpath=currentpath2.slice(0);
	newpath[1]=param;
	newpath.length=2;
	switchtoView(newpath.join("/"));
}


changeDisplay("contacts","menu_picture");
changeDisplay("contacts","menu_contact");
changeDisplay("contacts","menu_contact2");
changeDisplay("contacts","menu_contacts_send");
changeDisplay("contacts","menu_contacts_views");
changeDisplay("contacts/detail/attachment","menu_global_attachments");
changeDisplay("contacts","menu_global_tags");
function menuswitchContactView(param) {
	var newpath=currentpath2.slice(0);
	newpath[1]=param;
	switch (param)	{
		case "phonelist":
		case "cards":
			newpath.length=2;
			break;
		case "detail":
			newpath[2]="overview";
			newpath.length=3;
			break;
	}
	switchtoView(newpath.join("/"));
}
function menuswitchContactDetail(param) {
	var newpath=currentpath2.slice(0);
	newpath[2]=param;
	newpath.length=3;
	switchtoView(newpath.join("/"));
}


changeDisplay("contact_new","menu_save");
changeDisplay("contact_new/personal","menu_contact_new_picture");
changeDisplay("contact_new/distributionlist","menu_new_contact_distributionlist");
changeDisplay("contact_new/attachment","menu_calendar_new_attachment");
changeDisplay("contact_new","menu_dyn_window");

function menuswitchContactNew(param) {
	var newpath=currentpath2.slice(0);
	newpath[1]=param;
	newpath.length=2;
	switchtoView(newpath.join("/"));
}

changeDisplay("infostore","menu_picture");
changeDisplay("infostore","menu_infostore");
changeDisplay("infostore","menu_infostore2");
changeDisplay("infostore","menu_infostore_views");
changeDisplay("infostore","menu_infostore_send");
changeDisplay("infostore","menu_global_tags");
changeDisplay("infostore/split/version","menu_infostore_version");
function menuswitchInfoStoreView(param) {
	var newpath=currentpath2.slice(0);
	newpath[1]=param;
	switch (param)	{
		case "list":
		case "split":
			newpath.length=2;
			break;
		case "detail":
			newpath[2]="overview";
			newpath.length=3;
			break;
	}
	switchtoView(newpath.join("/"));
}
function menuswitchInfoStoreDetail(param) {
	var newpath=currentpath2.slice(0);
	newpath[2]=param;
	newpath.length=3;
	switchtoView(newpath.join("/"));
}


changeDisplay("infostore_new","menu_save");
changeDisplay("infostore_new","menu_dyn_window");

changeDisplay("tasks","menu_picture");
changeDisplay("tasks","menu_tasks");
changeDisplay("tasks","menu_tasks_views");
changeDisplay("tasks","menu_global_tags");

changeDisplay("tasks/split/attachment","menu_global_attachments");
changeDisplay("tasks/split","menu_global_confirmation");
function menuswitchTaskView(param) {
	var newpath=currentpath2.slice(0);
	newpath[1]=param;	
	switch (param)	{
	case "list":
		case "split":
			newpath.length=2;
			break;
		case "detail":
			newpath[2]="overview";
			newpath.length=3;
			break;
	}
	switchtoView(newpath.join("/"));
}
function menuswitchTaskDetail(param) {
	var newpath=currentpath2.slice(0);
	newpath[2]=param;
	newpath.length=3;
	switchtoView(newpath.join("/"));
}

changeDisplay("task_new","menu_save");
changeDisplay("task_new/participant","menu_task_new_participant");
changeDisplay("task_new/attachment","menu_calendar_new_attachment");
changeDisplay("task_new","menu_dyn_window");

function menuswitchTaskNew(param) {
	var newpath=currentpath2.slice(0);
	newpath[1]=param;
	newpath.length=2;
	switchtoView(newpath.join("/"));
}

//changeDisplay("configuration","menu_save");
changeDisplay("configuration/settings","menu_save");
changeDisplay("configuration/import","menu_import");
changeDisplay("configuration/tags","menu_save");
changeDisplay("configuration/portal","menu_save");
changeDisplay("configuration/mail","menu_save");
changeDisplay("configuration/calendar","menu_save");
changeDisplay("configuration/contacts","menu_save");
changeDisplay("configuration/tasks","menu_save");

changeDisplay("configuration/infostore","menu_save");
changeDisplay("configuration/folder/overview","menu_save");
changeDisplay("configuration/folder/overview","menu_configuration_folder");
changeDisplay("configuration/folder/rights","menu_save");
changeDisplay("configuration/folder/rights","menu_configuration_user");
changeDisplay("configuration/folder/rights","menu_configuration_folderright_folder");
changeDisplay("configuration/folder/rights","menu_configuration_objectright_read");
changeDisplay("configuration/folder/rights","menu_configuration_objectright_write");
changeDisplay("configuration/folder/rights","menu_configuration_objectright_delete");
changeDisplay("configuration/folder/rights","menu_configuration_adminright");
changeDisplay("configuration/mail/signatures","menu_config_mail_signatures");
changeDisplay("configuration/portal/external","menu_config_portal_external");
changeDisplay("configuration/portal/external","menu_config_portal_external2");

changeDisplay("configuration/calendar/teams","menu_configuration_teams_teams");
changeDisplay("configuration/tags","menu_configuration_settings_categories");

function menuswitchConfigurationFolderView(param) {
	var newpath=currentpath2.slice(0);
	newpath[2]=param;
	newpath.length=3;
	switchtoView(newpath.join("/"));
}
/********************************** First of all *****************************************************************/
function menufollowLink(mymodule,object) {
	if(mymodule=="task") { mymodule="tasks" } 
	
	//triggerEvent("OX_Switch_View",mymodule);
	var view=mymodule+"/detail/overview";
	activefolder=object.folder;
	if(!object.folder_id && object.folder) {
		object.folder_id=object.folder;
	}
	if(!object.module) {
		object.module=mymodule;
	}
	menucountselected=1;
	menucountsubselected=0;
	oArray=new Array();
	oArray.push(object);
	switch(mymodule) {
		case "infostore":
		    view = menulastviews[mymodule] || mymodule+"/split/overview";
		    if (object.id) {
		    	view = mymodule+"/split/overview";
		    	object["directLink"] = true;
		    	oLastSelectedInfoObject = new Array();
		    	oLastSelectedInfoObject[0] = object;
		    }		
			break;
		case "contacts":		    
		    if (object.id) {
		    	object["directLink"] = true;
		    	contactDetailId = object;
		    } else {
		    	view = menulastviews[mymodule] || configGetKey("gui.contacts.view");
		    }
			break;
		case "calendar":
		    if (object.id) {
		    	object["directLink"] = true;
			    selectedAppointment = object;
		    } else {
		        view = menulastviews[mymodule] || configGetKey("gui.calendar.view");
		    }
			break;
		case "tasks":
		    view = menulastviews[mymodule] || configGetKey("gui.tasks.view");
		    if (object.id) {
	    	    view = mymodule+"/split/overview";
			    object["directLink"] = true;
			    activeTaskId = new Array();
			    activeTaskId[0]=object;
		    }	
			break;
		case "mail":
		    view = menulastviews[mymodule] || configGetKey("gui.mail.view");
		    if (object.id) {
			    if (view.match(/mail\/list/gi)) view = mymodule + "/hsplit/unthreaded";
			    object["directLink"]=true;
                mail_lastSelectedId=object;
		    }
	}
	var folderChanged = (activefolder == object.folder);
	setActiveFolder(object.folder,function() {
		triggerEvent("OX_Switch_View",view, (folderChanged ? "samefolder" : "newfolder"));
		triggerEvent("Selected",oArray);
	},null,true);			
}
function cloneMenuforPopup(clonemodule) {
	var mynode=$("all_of_menu").cloneNode(true);
	var allattributes=mynode.getElementsByTagName("td");
	var removeNode = new Array();
	var len=allattributes.length;
	for (i=0;i<len;i++) {
		var tmptd=allattributes[i];
		if(tmptd.attributes) {
			if(tmptd.getAttribute("oxmodule"))
			{
				var mymodules=tmptd.getAttribute("oxmodule");
				var splitmodules=mymodules.split(",");
				var ismodule=false;
				for(zaehler=0;zaehler<splitmodules.length;zaehler++) {
					if(splitmodules[zaehler]==clonemodule) {
						ismodule=true;
					}
				}
				if(!ismodule) {
					removeNode.push(tmptd);
				}
			}
		}
	}
	for (i=0;i<removeNode.length;i++){
		removeNode[i].parentNode.removeChild(removeNode[i]);
	}
}	
/********************************** Menu Init Functions ***************************************************************************/
function loadmenu()
{
	menuinit(activemodule);
	addDOMEvent($("menu_error"),"mousedown",function() {
		blockremoveerrors=true;
	});
}
var menuselectstart=false;
var menumousedown=false;
function menuinit(newmodule)
{
	if(newmodule)
	{
		activemodule=newmodule;
	}
	$("all_of_menu").onselectstart = function () { var tmp=menuselectstart ; menuselectstart = false; return tmp; }  
	$("all_of_menu").onmousedown = function () { var tmp=menumousedown ; menumousedown = false; return tmp; }
	if($("menu_search_mail_searchfield")) {
		$("menu_search_mail_searchfield").onselectstart = function () {
			menuselectstart=true;
		}
		$("menu_search_mail_searchfield").onmousedown = function () {
			menumousedown=true;
		}
	} 
	if($("menu_search_global_searchfield")) {
		$("menu_search_global_searchfield").onselectstart = function () {
			menuselectstart=true;
		}
		$("menu_search_global_searchfield").onmousedown = function () {
			menumousedown=true;
		}
        globalSearchMenu = new PulldownMenu($("menu_search_context"));
        /**
         * Populates the pulldown menu with available search fields.
         * @param {Array} fields An array of strings which specify
         * the machine-readable field names (e. g. as used in the HTTP API).
         * When this parameter not present or an empty array, the pulldown
         * arrow is hidden.
         * @param {Array} names An array of I18nString objects which specify
         * the human-readable field names. Each entry corresponds to one in
         * <code>fields</code>.
         * @param {Object} checked An optional set of initially active fields.
         * Each member corresponds to and has the same name as an entry in
         * <code>fields</code>. The values are booleans. Defaults to all false.
         */
        globalSearchMenu.setFields = function(fields, names, checked) {
            this.removeAllItems();
            if (fields && fields.length) {
                this.checked = checked;
                for (var i = 0; i < fields.length; i++) {
                    var item = new MenuItem(names[i], function() {
                        globalSearchMenu.checked[this.searchField] =
                            this.getChecked();
                        globalSearchMenu.onChange();
                    });
                    item.searchField = fields[i];
                    item.setChecked(globalSearchMenu.checked[fields[i]]);
                    globalSearchMenu.addItem(item);
                }
                $("menu_search_context").style.display = "";
            } else {
                $("menu_search_context").style.display = "none";
            }
        }
	} 
	
	register("OX_Configuration_Loaded", function(){
		if(currentpath.length==0) {
			if(configContainsKey("gui.menu.menuiteration")) {
				menuiteration=configGetKey("gui.menu.menuiteration");
			}
			menuHeightChange(true);
			
			var module = location.hash.match(/[#&]m=([^#&]+)/);
			var folder = location.hash.match(/[#&]f=([^#&]+)/);
			var id = location.hash.match(/[#&]i=([^#&]+)/);
			
			activemodule = "portal"; // fallback to portal			
			if (module && folder && id) {
				// direct link, nothing to do here ...
                activemodule = module;
                activefolder = folder;
                return;
            }
			
			// iterating through all available modules after login and 
			// active the first module we found which is enabled. we also try
			// to select the standard folder of this module
			for (var i=0; i < modules.length; i++) {
				var module = modules[i];
				if (module.disable) continue;
				activemodule = module["name"];
				switch(activemodule) {
					case "portal": 
					   activefolder=null; 
					   break;
					case "mail":
					   activefolder=configGetKey("mail.folder.inbox");
					   // checking the default folder of mail
					   // if it's null or empty somethings broken in the 
					   // mail backend and we can't connect to the mail server 
					   if (!activefolder) {
					   	   // to prevent further errors we disable the mail module
					   	   // and keep on iterating
					   	   module.disable = true;
					   	   configSetKey("modules.mail.module", false);
					   	   addModuleIcon({ name: module.name, 
					   	       text: module.text, prio: module.priority, 
					   	       disable: true });

					   	   newAlert(_("The E-Mail module is not available"), 
					   	       _("Unable to establish a connection to the E-Mail server. Possible reasons: the mail server is (temporarily) down or there are network connection problems. To prevent further errors the module has been disabled. Please contact your administrator."), /**i18n**/
					   	       null);
					   	   continue;
					   }
					   break;
					default: 
					   activefolder=configGetKey("folder."+module["name"]); 
					   break;
				}
                break;
			}

            if (activefolder && oMainFolderTree) setActiveFolder(activefolder);
            triggerEvent("OX_Switch_Module",activemodule);
            triggerEvent("OX_Selected_Attachments",0);
		}
	});
	
}
/*** Search Functions ***/
var menumailsearchcontents=["from","to","cc","subject","mailtext"];
var mailsearchcontent=0;
function menu_setSearchField(field) {
	mailsearchcontent=-1;
	for(var i=0;i<menumailsearchcontents.length;i++) {
		if(menumailsearchcontents[i]==field) {
			mailsearchcontent=i; break;
		}
	}
}

function menudoSearchMail() {
	var param=$('menu_search_mail_searchfield').value;
	triggerEvent("OX_New_Search","mail",param,menumailsearchcontents[mailsearchcontent]); 
}
function menuclearSearchMail() {
	if($("menu_search_mail_searchfield")) $('menu_search_mail_searchfield').value="";
}

function menudoSearch() {
	var param=$('menu_search_global_searchfield').value;
	triggerEvent("OX_New_Search",activemodule,param); 
}
function menuclearSearch() {
	if($("menu_search_global_searchfield")) $('menu_search_global_searchfield').value="";
}

function menuSearchClicked(event) {
	if(event.keyCode == 13) {
		menudoSearch();
	}
}
function menuSearchClickedMail(event) {
	if(event.keyCode == 13) {
		menudoSearchMail();
	}
}

/*** Options Menu ******************************************************************************************************************/
function changeDisplayDynamic(dynamiccontent,bool)
{
	for (zaehler in dynamiccontents[activemodule])
	{
		if(dynamiccontents[activemodule][zaehler]["content"].id == dynamiccontent && currentpath2.join("/").indexOf(dynamiccontents[activemodule][zaehler]["view"])==0) {
			if(bool) {
				dynamiccontents[activemodule][zaehler]["display"]="";
			} else {
				dynamiccontents[activemodule][zaehler]["display"]="none";
			}
			break;
		}	
	}
	reloadDynamicContent();
}

function optionsmenuchangestatus(elementid,mystatus)
{
	if(mystatus)
	{
		var mytr = elementid;
		mytr.className="smallpopupactive border-color-PMG-selection-elements font-color-default background-color-content";
	}
	else
	{
		var mytr=elementid;
		mytr.className="smallpopupnotactive background-color-content font-color-default background-color-content";
	}
}
/******************** End of Options ****************************************************************************************** */
/************************** Panelhelp ********************************************************************************************/
function showPanelHelp(myboolean)
{
	menu_showhelp=myboolean;
	if(myboolean) {
		$("menu_help").style.display=""
	}
	else {
		$("menu_help").style.display="none";
	}
	triggerEvent("OX_menu_RESIZE");
}	
/************************* Error Panel*******************************************************************************/
function addErrorMessage(priority,errormessage)
{
	if(priority>0 && priority<5)
	{
		if(!errormessages[priority])
		{
			errormessages[priority]=new Array();
		}
		errormessages[priority].push(errormessage);
	}
	showErrors1();
}
function addInfoMessage(priority,infomessage) {
	if(priority>0 && priority<5)
	{
		if(!infomessages[priority])
		{
			infomessages[priority]=new Array();
		}
		infomessages[priority].push(infomessage);
	}
	showErrors1();
}
function menuremoveErrors(priority)
{
	var refillmenu=false;
	for(;priority<5;priority++)
	{
		if(errormessages[priority] && errormessages[priority].length != 0)
		{
			errormessages[priority]=new Array();
			refillmenu=true;
		}
		if(infomessages[priority] && infomessages[priority].length != 0)
		{
			infomessages[priority]=new Array();
			refillmenu=true;
		}
	}
	if(refillmenu)
	{
		showErrors1();
	}
}		
function showErrors1()
{
	var showerrors=false;
	var d=$("error_panel");
	d.innerHTML="";
	for(errorprio=4;errorprio>0;errorprio--)
	{
		if(errormessages[errorprio])
		{
			for (i=0;i<errormessages[errorprio].length;i++)
			{
				showerrors=true;
				var diverror=document.createElement("div");
				diverror.style.whiteSpace="normal";
				if(errorprio==4) {
//					diverror.className="warningtext";
					diverror.className="errortext font-color-error";
				}
				else {
					diverror.className="errortext font-color-error";
				}
				diverror.appendChild(document.createTextNode(errormessages[errorprio][i]));
				d.appendChild(diverror);
			}
		}
		if(infomessages[errorprio])
		{
			for (i=0;i<infomessages[errorprio].length;i++)
			{
				showerrors=true;
				var diverror=document.createElement("div");
				diverror.style.whiteSpace="normal";
				diverror.className="infotext font-color-info";
				diverror.appendChild(document.createTextNode(infomessages[errorprio][i]));
				d.appendChild(diverror);
			}
		}
	}
	if(showerrors)
	{
		$("menu_error").style.display="";
	}
	else
	{
		$("menu_error").style.display="none";
	}
	window.setTimeout(function(){triggerEvent("OX_menu_RESIZE");},0);
}


function changeClassAttributes(classname,element,value) {
	try {
		//Check Browser
		var pathtorules;
		if (document.all) { pathtorules = 'rules'; }
		else if (document.getElementById)  { pathtorules = 'cssRules'; }
		for(var i=0;i<document.styleSheets.length;i++) {
			var item=document.styleSheets.item(i);
			for(var i2=0;i2<item[pathtorules].length;i2++) {
				var rule=item[pathtorules].item(i2);
				if(rule.selectorText==classname) {
					rule.style[element]=value;
				}
			}
		}
	} catch (ex) {}
}


function afterLogin() {
	
	new JSON().get("config/diemenu?session="+session, null, new function(reply) {
		if(reply) {
			if(reply.error) {
				alert(reply.error);
			}
			if (reply.oxlayout) {
				oxlayout=reply.oxlayout;
			}			
		} else {
			alert(_("No server connection"));
		}
	});
}

function changePopMenuModules(mymodule) {
	for(zaehler in allcontentspicturepopup) {
		for (zaehler2 in allcontentspicturepopup[zaehler]) {
			allcontentspicturepopup[zaehler][zaehler2].style.display="none";
		}
	}
	for (zaehler2 in allcontentspicturepopup[mymodule]) {
		allcontentspicturepopup[newmodule][zaehler2].style.display="block";
	}
}

helpevents.register("help",doHelpMessage);

function doHelpMessage(stringtoshow){
	$("menu_help_text").firstChild.nodeValue=stringtoshow;
}

function showPictureOptions() {
	var hallo=$("menu_picture_pfeil_unten");
	var mypopupmenu=$("menu_popup_picture");
	mypopupmenu.style.top=(hallo.offsetTop+hallo.offsetHeight+3)+"px";
	mypopupmenu.style.left=(hallo.offsetLeft-7)+"px;";
	mypopupmenu.style.zIndex="150";
	mypopupmenu.style.display="block";
}

function menuHeightChange(cancelHeightChange) {
	
	if(menuiteration<menumaxiteration) {
		if(!cancelHeightChange) {
			menuiteration++;
		}
		if(menuiteration==menumaxiteration) {
			$("menu_options_arrow_down").style.display="none";
			$("menu_options_arrow_up").style.display="block";
		}
	} else {
		if(!cancelHeightChange) {
			menuiteration=menuminiteration;
		}
		$("menu_options_arrow_down").style.display="block";
		$("menu_options_arrow_up").style.display="none";
	}
	try {
		if(corewindow==window) { configSetKey("gui.menu.menuiteration",menuiteration); }
		changeClassAttributes(".backgroundheight","height",((menuiteration*menuiterationheight)+(menupadding))+"em");
	} catch(e) {}
	
	triggerEvent("OX_menu_RESIZE");
}

function resizeMenuSplit() {
	
	var contentheight=(menuiteration*menuiterationheight+(menupadding));
	
	var helpheight=menuhelpheight;
	if($("menu_help").style.display=="none") {
		helpheight=0;
	}
	
	var errorheight=erroriteration*menuerrorheight;
	if($("menu_error").style.display=="none") {
		errorheight=0;
	}
	
	var h = (headerheight+arrowheight+contentheight+helpheight+errorheight+2)+"em";
	try {
		resizeSplit("all_of_menu", h); 
	} catch (e)	{}
}

function menuHeightChangePicture() {
	if(menuisActive("menu_picture")) {
		fillsmallsymbols(menuiteration,activemodule);
	}
}

register("OX_Switched",function() {
	if(menuisActive("menu_picture")) {
		fillsmallsymbols(menuiteration,activemodule);
	}	
});

var modulesinpicturemenu=new Object();
function fillsmallsymbols(iteration,mymodule) {
	
	modulesinpicturemenu=new Object();
	var zeigeobjekte=(iteration-3)*2
	var zaehler=0;
	
	for (zaehler1 in modules) {
		if(mymodule==modules[zaehler1]["name"]) {
			if(document.getElementById("menu_small_"+modules[zaehler1]["name"])) {
				document.getElementById("menu_small_"+modules[zaehler1]["name"]).style.display="none";		
				if(modules[zaehler1]["name"]=="contacts" && configGetKey("modules.contacts.module")) {
					if(zaehler<zeigeobjekte) {						
						document.getElementById("menu_small_distributionlist").style.display="";		
						zaehler++;					
					} else {
						modulesinpicturemenu["distributionlist"]=true;
						document.getElementById("menu_small_distributionlist").style.display="none";		
					}
				}
			}
		} else {
			if(zaehler<zeigeobjekte) {
				if($("menu_small_"+modules[zaehler1]["name"])) {
					if(mymodule == "portal" && modules[zaehler1]["name"] == "mail") {
						$("menu_small_"+modules[zaehler1]["name"]).style.display="none";	
					} else {
						if(configGetKey("modules."+modules[zaehler1]["name"]+".module")) {
							$("menu_small_"+modules[zaehler1]["name"]).style.display="";		
							zaehler++;
							if(modules[zaehler1]["name"]=="contacts" && configGetKey("modules.contacts.module")) {
								if(zaehler<zeigeobjekte) {
									$("menu_small_distributionlist").style.display="";
									zaehler++;					
								} else {
									modulesinpicturemenu["distributionlist"]=true;
									$("menu_small_distributionlist").style.display="none";
								}
							}
						} else {
							$("menu_small_"+modules[zaehler1]["name"]).style.display="none";
						}
					}
				}			
			} else {
				if($("menu_small_"+modules[zaehler1]["name"])) {
					if(modules[zaehler1]["name"]=="contacts") {
						modulesinpicturemenu["distributionlist"]=true;
						$("menu_small_distributionlist").style.display="none";
					}
					modulesinpicturemenu[modules[zaehler1]["name"]]=true;
					$("menu_small_"+modules[zaehler1]["name"]).style.display="none";
				}	
			}
		}
	}
	
	// count enabled modules
	var enabled_modules = 0;
	for (i = 0; i < modules.length; i++) {
		switch(modules[i].name) {
			case "contacts":
				if (!modules[i].disable) enabled_modules++; // double
				// nobreak
			case "mail":
			case "calendar":
			case "tasks":
			case "infostore":
				if (!modules[i].disable) enabled_modules++;
				break;
		}
	}
	// show arrow?	
	var zeigepfeil = enabled_modules > (iteration-3)*2+1;

	$("menu_picture_normal").style.display = (zeigeobjekte == 0) ? "none" : "";
	$("menu_picture_contextmenu_na").style.display= zeigepfeil ? "none" : "";
	$("menu_picture_contextmenu").style.display= zeigepfeil ? "" : "none";
}

function reloadDynamicContent()
{
	setTimeout(function() { showElement(status_content,activemodule); },0);
}
var startme=new Object();
function startit(param) {
	startme[param]=new Date().getTime();
}
function endit(status) {
	var end=new Date().getTime();
	startme[status]=new Date().getTime();
}
function showElement(mystatus,mymodule)
{	
  	var mycontents;   
  	var restmain=0;   
	var showscroller = false;
	var showscrollerlast = -1;
	var einzaehler = -1;
	var validcontents=new Object();
	var notvalidcontents=new Object();
	
	for(zaehler2 in dynamiccontents) {
		for(var zaehler3 in dynamiccontents[zaehler2]) {
			var isvalid=false;
			if(zaehler2==mymodule) {
				if(currentpath2.join("/").indexOf(dynamiccontents[mymodule][zaehler3]["view"]) == 0) {
					einzaehler++;
					if(dynamiccontents[mymodule][zaehler3]["display"]!="none") {
						showscrollerlast=einzaehler;showscroller=true;isvalid=true;
						validcontents[dynamiccontents[mymodule][zaehler3]["content"].id]=dynamiccontents[mymodule][zaehler3]["content"];			
					}
				}
			}
			if(!isvalid) {
				notvalidcontents[dynamiccontents[zaehler2][zaehler3]["content"].id]=dynamiccontents[zaehler2][zaehler3]["content"];
			}		
		}
	}

	for(var zaehler3 in notvalidcontents) {
		if(validcontents[zaehler3]) {
			delete notvalidcontents[zaehler3];
		}
	}
	
	if(!showscroller || mystatus == 0) {
		hideNode("menu_dynamic_leftscroll_active",true);
		if($("menu_dynamic_leftscroll_active").style.display!="none") { 	
			hideNode("menu_dynamic_leftscroll_active");
			$("menu_dynamic_leftscroll_active").style.display="none"; 
		}
	}
	if(!showscroller || mystatus != 0) {
		hideNode("menu_dynamic_leftscroll_not_active",true);
		if($("menu_dynamic_leftscroll_not_active").style.display!="none") {
			$("menu_dynamic_leftscroll_not_active").style.display="none"; 
		}
	}
	if(!showscroller || mystatus >=(showscrollerlast)) {
		hideNode("menu_dynamic_rightscroll_active",true);
		if($("menu_dynamic_rightscroll_active").style.display!="none") {  
			$("menu_dynamic_rightscroll_active").style.display="none"; 
		}
	}
	if(!showscroller || mystatus <(showscrollerlast)) {
		hideNode("menu_dynamic_rightscroll_not_active",true);
		if($("menu_dynamic_rightscroll_not_active").style.display!="none") { $("menu_dynamic_rightscroll_not_active").style.display="none"; }
	}
	if(showscroller && mystatus == 0) { 
		showNode("menu_dynamic_leftscroll_not_active",true);
		if($("menu_dynamic_leftscroll_not_active").style.display!="") { $("menu_dynamic_leftscroll_not_active").style.display=""; }
	}
	if(showscroller && mystatus != 0) {
		showNode("menu_dynamic_leftscroll_active",true);
		if($("menu_dynamic_leftscroll_active").style.display!="") { $("menu_dynamic_leftscroll_active").style.display=""; }
	}
	if(showscroller && mystatus>=(showscrollerlast)) {
		showNode("menu_dynamic_rightscroll_not_active",true);
		if($("menu_dynamic_rightscroll_not_active").style.display!="") { $("menu_dynamic_rightscroll_not_active").style.display=""; }
	}
	if(showscroller && mystatus<(showscrollerlast)) {
		showNode("menu_dynamic_rightscroll_active",true);
		if($("menu_dynamic_rightscroll_active").style.display!="") { $("menu_dynamic_rightscroll_active").style.display=""; }
	}
	if(!showscroller) { restmain=0; }
	else {
		restmain=$("menu_dynamic_content").scrollWidth;
		restmain=restmain-20;
	}
	for(var zaehler3 in notvalidcontents) {
		hideNode(notvalidcontents[zaehler3].id,true);
		if(notvalidcontents[zaehler3].style.display!="none") {
			notvalidcontents[zaehler3].style.display="none";
		}
	}
	var einzaehler=0;
	var mybool = true;	
	for (zaehlercontents in validcontents) {
		if(einzaehler>=mystatus) {
			if(mybool) {
				validcontents[zaehlercontents].style.visibility="hidden";
				validcontents[zaehlercontents].style.display="";
				if(validcontents[zaehlercontents].offsetWidth<restmain) {
					restmain=restmain-validcontents[zaehlercontents].offsetWidth;
					showNode(validcontents[zaehlercontents].id,true);
					validcontents[zaehlercontents].style.visibility="visible";
					if(validcontents[zaehlercontents].style.display!="") {
						validcontents[zaehlercontents].style.display="";
					}	
				} else {
					hideNode(validcontents[zaehlercontents].id,true);
					if(validcontents[zaehlercontents].style.display!="none") {
						validcontents[zaehlercontents].style.display="none";	
					}
					mybool=false;
				}
			}		
		}
		else {
			break;
		}
		einzaehler++;
	}	
}
function menu_portal_quick_settings_content_change_password()
{
	triggerEvent("OX_Change_Password_Click");
}


/**
 * Resizes the scrollable area in the menu.
 */


function scrollleft()
{
	myint=status_content-1;
	for (myint;myint>=0;myint--) 
	{
		if(dynamiccontents[activemodule][myint]["display"]!="none")
		{
			status_content=myint;
			break;
		}
	}
	reloadDynamicContent();	
}
function scrollright()
{
	myint=status_content+1;
	for (myint;myint<dynamiccontents[activemodule].length;myint++)
	{ 
		if(dynamiccontents[activemodule][myint]["display"]!="none")
		{
			status_content=myint;
			break;
		}
	}
	reloadDynamicContent();
}
function moduledynamiclength()
{
	return dynamiccontents[activemodule].length;
}
fileloaded();